@@ -1,7 +1,7 @@
 package Perinci::CmdLine::POD;
 
 our $DATE = '2017-02-24'; # DATE
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 use 5.010001;
 use strict;
@@ -350,7 +350,10 @@ sub gen_pod_for_pericmd_script {
         $program_name = $args{script};
         $program_name =~ s!.+/!!;
     }
-    $program_name //= "program";
+    if (!$program_name && defined $args{url} && $args{url} =~ m!.+/([^/]+)\z!) {
+        $program_name = $1;
+    }
+    $program_name //= "PROGRAM";
     my $summary = $args{summary} // $cli->{summary} //
         $metas{''}{summary} // '(no summary)';
 
@@ -449,14 +452,6 @@ sub gen_pod_for_pericmd_script {
                                     die sprintf("Example #%d (subcommand %s): cmdline %s: failed: %s", $eg->{_i}, $eg->{_sc_name}, $cmdline, explain_child_error());
                                 }
                             }
-                            if (my $max_lines = $eg->{example_spec}{'x.doc.max_result_lines'}) {
-                                my @lines = split /^/, $fres;
-                                if (@lines > $max_lines) {
-                                    my $n = int($max_lines/2);
-                                    splice @lines, $n, (@lines - $max_lines + 1), "...\n";
-                                    $fres = join("", @lines);
-                                }
-                            }
                             #$self->log_debug(["fres: %s", $fres]);
                         } else {
                             warn sprintf("Example #%d (subcommand %s) has src with unsupported src_plang ($eg->{srg_plang}), skipped showing result", $eg->{_i}, $eg->{_sc_name});
@@ -483,6 +478,15 @@ sub gen_pod_for_pericmd_script {
                         $fres = Perinci::Result::Format::Lite::format($res, $format);
                     }
 
+                    if (my $max_lines = $eg->{example_spec}{'x.doc.max_result_lines'}) {
+                        my @lines = split /^/, $fres;
+                        if (@lines > $max_lines) {
+                            my $n = int($max_lines/2);
+                            splice @lines, $n, (@lines - $max_lines + 1), "...\n";
+                            $fres = join("", @lines);
+                        }
+                    }
+
                     $fres =~ s/^/ /gm;
                     push @sectpod, $fres;
                     push @sectpod, "\n";
@@ -970,7 +974,7 @@ Perinci::CmdLine::POD - Generate POD for Perinci::CmdLine-based CLI script
 
 =head1 VERSION
 
-This document describes version 0.010 of Perinci::CmdLine::POD (from Perl distribution Perinci-CmdLine-POD), released on 2017-02-24.
+This document describes version 0.011 of Perinci::CmdLine::POD (from Perl distribution Perinci-CmdLine-POD), released on 2017-02-24.
 
 =head1 SYNOPSIS
 
